@@ -49,10 +49,10 @@ double whimed(double *a, double *w, int n,
 /* --------- ./mc.c -------- */
 
 /* call via .C() from R : */
-void mc_C(double *z, int *n, double *eps, int *iter, double *out);
+void mc_C(double *z, int *in, double *eps, int *iter, double *out, int *scale);
 
-/* call from C: *iter and *eps  are both input and output */
-double mc_C_d(double *z, int n, double *eps, int *iter);
+/* call from C: *iter is both input and output */
+double mc_C_d(double *z, int n, const double eps[], int *iter, int scale);
 
 
 
